deser_stringified_format

Function deser_stringified_format 

pub fn deser_stringified_format<'de, D, T, F, E>(
    deserializer: D,
    parser: F,
) -> Result<T, D::Error>
where D: Deserializer<'de>, T: DeserializeOwned, F: Fn(&str) -> Result<T, E>, E: Display,
deserialize a stringified field embedded in other data using a custom parser, allowing you to parse JSON, YAML, or any other serde-compatible format.