pub fn deser_stringified_format<'de, D, T, F, E>(
deserializer: D,
parser: F,
) -> Result<T, D::Error>Expand description
deserialize a stringified field embedded in other data using a custom parser, allowing you to parse JSON, YAML, or any other serde-compatible format.